==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/events/MapAuthEventEntityDelegate.java <==
package org.keycloak.models.map.events;
public class MapAuthEventEntityDelegate implements org.keycloak.models.map.events.MapAuthEventEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAuthEventEntity> delegateProvider;
    public MapAuthEventEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAuthEventEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.ID, id).setId(id);
    }
    @Override public Long getExpiration() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.EXPIRATION).getExpiration();
    }
    @Override public void setExpiration(Long expiration) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.EXPIRATION, expiration).setExpiration(expiration);
    }
    @Override public Long getTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.TIMESTAMP).getTimestamp();
    }
    @Override public void setTimestamp(Long timestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.TIMESTAMP, timestamp).setTimestamp(timestamp);
    }
    @Override public org.keycloak.events.EventType getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.TYPE).getType();
    }
    @Override public void setType(org.keycloak.events.EventType type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.TYPE, type).setType(type);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getClientId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.CLIENT_ID).getClientId();
    }
    @Override public void setClientId(String clientId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.CLIENT_ID, clientId).setClientId(clientId);
    }
    @Override public String getUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.USER_ID).getUserId();
    }
    @Override public void setUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.USER_ID, userId).setUserId(userId);
    }
    @Override public String getSessionId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.SESSION_ID).getSessionId();
    }
    @Override public void setSessionId(String sessionId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.SESSION_ID, sessionId).setSessionId(sessionId);
    }
    @Override public String getIpAddress() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.IP_ADDRESS).getIpAddress();
    }
    @Override public void setIpAddress(String ipAddress) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.IP_ADDRESS, ipAddress).setIpAddress(ipAddress);
    }
    @Override public String getError() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.ERROR).getError();
    }
    @Override public void setError(String error) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.ERROR, error).setError(error);
    }
    @Override public java.util.Map<String,String> getDetails() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.DETAILS).getDetails();
    }
    @Override public void setDetails(java.util.Map<String,String> details) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.DETAILS, details).setDetails(details);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/events/MapAuthEventEntityDelegate.java <==
package org.keycloak.models.map.events;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthEventEntityDelegate implements org.keycloak.models.map.events.MapAuthEventEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.events.MapAuthEventEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAuthEventEntity> delegateProvider;
    public MapAuthEventEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAuthEventEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAuthEventEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.ID, id).setId(id);
    }
    @Override public Long getExpiration() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.EXPIRATION).getExpiration();
    }
    @Override public void setExpiration(Long expiration) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.EXPIRATION, expiration).setExpiration(expiration);
    }
    @Override public Long getTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.TIMESTAMP).getTimestamp();
    }
    @Override public void setTimestamp(Long timestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.TIMESTAMP, timestamp).setTimestamp(timestamp);
    }
    @Override public org.keycloak.events.EventType getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.TYPE).getType();
    }
    @Override public void setType(org.keycloak.events.EventType type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.TYPE, type).setType(type);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getClientId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.CLIENT_ID).getClientId();
    }
    @Override public void setClientId(String clientId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.CLIENT_ID, clientId).setClientId(clientId);
    }
    @Override public String getUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.USER_ID).getUserId();
    }
    @Override public void setUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.USER_ID, userId).setUserId(userId);
    }
    @Override public String getSessionId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.SESSION_ID).getSessionId();
    }
    @Override public void setSessionId(String sessionId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.SESSION_ID, sessionId).setSessionId(sessionId);
    }
    @Override public String getIpAddress() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.IP_ADDRESS).getIpAddress();
    }
    @Override public void setIpAddress(String ipAddress) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.IP_ADDRESS, ipAddress).setIpAddress(ipAddress);
    }
    @Override public String getError() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.ERROR).getError();
    }
    @Override public void setError(String error) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.ERROR, error).setError(error);
    }
    @Override public java.util.Map<String,String> getDetails() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAuthEventEntityFields.DETAILS).getDetails();
    }
    @Override public void setDetails(java.util.Map<String,String> details) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAuthEventEntityFields.DETAILS, details).setDetails(details);
    }
}
